==> mdsr_0.2.5.tar.gz: mdsr/README.md <==

# mdsr <img src='man/figures/logo.png' align="right" height="139" />

![R-CMD-check](https://github.com/mdsr-book/mdsr/workflows/R-CMD-check/badge.svg)
[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/mdsr)](https://cran.r-project.org/package=mdsr)
[![CRAN RStudio mirror
downloads](https://cranlogs.r-pkg.org/badges/mdsr)](https://www.r-pkg.org/pkg/mdsr)

A complement to the CRC Press book [*Modern Data Science with
R*](https://mdsr-book.github.io/).

To install it, try:

``` r
install.packages("mdsr")
```

Load the package (like any other) with

``` r
library(mdsr)
```

## Cite

``` r
citation("mdsr")
```

    ## 
    ## To cite mdsr in publications use:
    ## 
    ##   Benjamin S. Baumer, Daniel T. Kaplan, Nicholas J. Horton (2021).
    ##   Modern Data Science with R. 2nd edition, Chapman and Hall/CRC Press:
    ##   Boca Raton, 1--673. URL
    ##   https://www.routledge.com/Modern-Data-Science-with-R/Baumer-Kaplan-Horton/p/book/9780367191498.
    ## 
    ## A BibTeX entry for LaTeX users is
    ## 
    ##   @Book{,
    ##     title = {Modern Data Science with {R}},
    ##     author = {Benjamin S. Baumer and Daniel T. Kaplan and Nicholas J. Horton},
    ##     publisher = {Chapman and Hall/CRC Press: Boca Raton},
    ##     year = {2021},
    ##     month = {3},
    ##     edition = {2nd},
    ##     pages = {1--673},
    ##     isbn = {9780367191498},
    ##     url = {https://www.routledge.com/Modern-Data-Science-with-R/Baumer-Kaplan-Horton/p/book/9780367191498},
    ##   }

==> mdsr_0.2.7.tar.gz: mdsr/README.md <==

# mdsr <img src='man/figures/logo.png' align="right" height="139" />

![R-CMD-check](https://github.com/mdsr-book/mdsr/workflows/R-CMD-check/badge.svg)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/mdsr)](https://cran.r-project.org/package=mdsr)
[![CRAN RStudio mirror
downloads](https://cranlogs.r-pkg.org/badges/mdsr)](https://www.r-pkg.org/pkg/mdsr)

A complement to the CRC Press book [*Modern Data Science with
R*](https://mdsr-book.github.io/).

To install it, try:

``` r
install.packages("mdsr")
```

The most recent version can always be installed directly from GitHub:

``` r
devtools::install_github("mdsr-book/mdsr")
```

Older versions of the package can be downloaded and installed via the
[CRAN archive](https://cran.r-project.org/src/contrib/Archive/mdsr/).

Load the package (like any other) with

``` r
library(mdsr)
```

## Cite

``` r
citation("mdsr")
```

    ## 
    ## To cite mdsr in publications use:
    ## 
    ##   Benjamin S. Baumer, Daniel T. Kaplan, Nicholas J. Horton (2021).
    ##   Modern Data Science with R. 2nd edition, Chapman and Hall/CRC Press:
    ##   Boca Raton, 1--673. URL
    ##   https://www.routledge.com/Modern-Data-Science-with-R/Baumer-Kaplan-Horton/p/book/9780367191498.
    ## 
    ## A BibTeX entry for LaTeX users is
    ## 
    ##   @Book{,
    ##     title = {Modern Data Science with {R}},
    ##     author = {Benjamin S. Baumer and Daniel T. Kaplan and Nicholas J. Horton},
    ##     publisher = {Chapman and Hall/CRC Press: Boca Raton},
    ##     year = {2021},
    ##     month = {3},
    ##     edition = {2nd},
    ##     pages = {1--673},
    ##     isbn = {9780367191498},
    ##     url = {https://www.routledge.com/Modern-Data-Science-with-R/Baumer-Kaplan-Horton/p/book/9780367191498},
    ##   }
